@@ -1,4 +1,4 @@
-/* $Id: mhub.c,v 1.5.4.1 2004/11/14 13:09:25 cegger Exp $
+/* $Id: mhub.c,v 1.7 2005/07/29 16:40:51 soyt Exp $
 ******************************************************************************
 
    mhub - A LibGII -> mouse protocol converter
@@ -54,7 +54,7 @@
 #define PROT_INTELLI	3
 
 typedef struct {
-	uint32 from, to;
+	uint32_t from, to;
 } remap;
 
 static char *progname;
@@ -75,7 +75,7 @@ static unsigned int min_extended_button = 4;
 static int wheel_up_button = 0;
 static int wheel_down_button = 0;
 
-static uint32 buttonstate = 0;
+static uint32_t buttonstate = 0;
 
 static const char missing_arg[] = "%s: missing argument for option '%c'\n";
 
@@ -357,11 +357,11 @@ open_outputs(void)
 
 
 static int
-output_intelli(int fd, uint32 butstate, int idx, int idy, int wheel)
+output_intelli(int fd, uint32_t butstate, int idx, int idy, int wheel)
 {
-	uint8 buf[4] = {0x40, 0x00, 0x00, 0x00};
-	sint8 dx = idx;
-	sint8 dy = idy;
+	uint8_t buf[4] = {0x40, 0x00, 0x00, 0x00};
+	int8_t dx = idx;
+	int8_t dy = idy;
 
 	buf[0] |= ((butstate & 0x01) << 5) | ((butstate & 0x02) << 3);
 	buf[3] |= ((butstate & 0x04) << 2) | ((butstate & 0x08) << 2);
@@ -380,9 +380,9 @@ output_intelli(int fd, uint32 butstate, int idx, int idy, int wheel)
 
 
 static int
-output_msc(int fd, uint32 butstate, int dx, int dy)
+output_msc(int fd, uint32_t butstate, int dx, int dy)
 {
-	uint8 buf[5] = {0x80, 0x00, 0x00, 0x00, 0x00};
+	uint8_t buf[5] = {0x80, 0x00, 0x00, 0x00, 0x00};
 	
 	buf[0] |= 0x07 ^ ( ((butstate&1) << 2) |
 			   ((butstate&2) >> 1) |
@@ -402,9 +402,9 @@ output_msc(int fd, uint32 butstate, int dx, int dy)
 
 
 static int
-output_ps2(int fd, uint32 butstate, int dx, int dy)
+output_ps2(int fd, uint32_t butstate, int dx, int dy)
 {
-	uint8 buf[3] = {0x08, 0x00, 0x00};
+	uint8_t buf[3] = {0x08, 0x00, 0x00};
 	
 	buf[0] |= (butstate & 0x07);
 	
@@ -430,9 +430,9 @@ output_ps2(int fd, uint32 butstate, int dx, int dy)
 
 
 static int
-output_extended(int fd, uint32 button, int nr, int press)
+output_extended(int fd, uint32_t button, int nr, int press)
 {
-	uint8 buf[2];
+	uint8_t buf[2];
 
 	buf[0] = button;
 	if (press) buf[0] |= (1<<7);
@@ -448,20 +448,20 @@ output_extended(int fd, uint32 button, int nr, int press)
 
 
 static int
-process_event(int press, uint32 butstate, uint32 button, int dx, int dy,
+process_event(int press, uint32_t butstate, uint32_t button, int dx, int dy,
 	      int dz, int wheel)
 {
 	int i;
 
 	if (wheel < 0 && wheel_up_button > 0) {
 		for (i = 0; i < num_butout; i++) {
-			output_extended(but_fds[i], (uint32)wheel_up_button,
+			output_extended(but_fds[i], (uint32_t)wheel_up_button,
 					-wheel, 0);
 		}
 	}
 	if (wheel > 0 && wheel_down_button > 0) {
 		for (i = 0; i < num_butout; i++) {
-			output_extended(but_fds[i], (uint32)wheel_down_button,
+			output_extended(but_fds[i], (uint32_t)wheel_down_button,
 					wheel, 0);
 		}
 	}
@@ -490,8 +490,8 @@ process_event(int press, uint32 butstate, uint32 button, int dx, int dy,
 }
 
 
-static inline uint32
-do_remap(uint32 button)
+static inline uint32_t
+do_remap(uint32_t button)
 {
 	int i;
 	
@@ -542,7 +542,7 @@ main(int argc, char *argv[])
 	if (!exit_on_sigpipe) signal(SIGPIPE, sigpipe_handler);
 
 	while ((giiEventRead(inp, &gev, emAll))) {
-		uint32 button;
+		uint32_t button;
 		switch (gev.any.type) {
 		case evPtrRelative:
 			if (debug) fprintf(stderr, 
