@@ -1,4 +1,4 @@
-/* $Id: unix.c,v 1.7 2004/05/12 09:44:49 pekberg Exp $
+/* $Id: unix.c,v 1.9 2005/01/21 11:22:04 pekberg Exp $
 ******************************************************************************
 
    LibGII core - Unix specific stuff.
@@ -27,6 +27,8 @@
 */
 
 #include "config.h"
+
+#include <ggi/gg.h>
 #include <ggi/internal/gii.h>
 #include <ggi/internal/gii_debug.h>
 #include <ggi/gii-unix.h>
@@ -35,9 +37,13 @@
 #include <string.h>
 #include <errno.h>
 
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #include <sys/types.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
@@ -147,10 +153,10 @@ giiEventPoll(gii_input *inp, gii_event_mask mask, struct timeval *timeout)
 	int	zero_timeout = 0;
 	gii_event_mask	tmpmask;
 	fd_set	allfds;
-
-	GIIDPRINT_EVENTS("giiEventPoll(%p, 0x%x, %p) called\n",
-			 inp, mask, timeout);
-
+	
+	DPRINT_EVENTS("giiEventPoll(%p, 0x%x, %p) called\n",
+		      inp, mask, timeout);
+	
 	if (inp->cache->havesafe) {
 		_giiSafeMove(inp, inp);
 	}
@@ -189,7 +195,7 @@ giiEventPoll(gii_input *inp, gii_event_mask mask, struct timeval *timeout)
 			return 0;
 		}
 
-		GIIDPRINT_EVENTS("giiEventPoll: starting non-polled loop\n");
+		DPRINT_EVENTS("giiEventPoll: starting non-polled loop\n");
 		while (1) {
 			struct timeval tmptv, *ptmptv;
 			int selectret;
@@ -257,7 +263,7 @@ giiEventPoll(gii_input *inp, gii_event_mask mask, struct timeval *timeout)
 
 	/* We have polled drivers, so we have to split the select and
 	   poll at regular intervals. */
-	GIIDPRINT_EVENTS("giiEventPoll: starting polled loop\n");
+	DPRINT_EVENTS("giiEventPoll: starting polled loop\n");
 	while (1) {
 		struct timeval tv;
 		int selectret, real_timeout;
@@ -701,7 +707,7 @@ void _giiUpdateCache(gii_input *inp)
 	fd_set	hlpfd;
 	int i;
 	
-	GIIDPRINT_CORE("_giiUpdateCache(%p) called\n", inp);
+	DPRINT_CORE("_giiUpdateCache(%p) called\n", inp);
 
 	FD_ZERO(&inp->cache->fdset);
 #ifdef USE_ASYNCPIPES
@@ -721,7 +727,7 @@ void _giiUpdateCache(gii_input *inp)
 
 			for (i = 0; i < sourcemax; i++) {
 				if (FD_ISSET(i, &hlpfd)) {
-					GIIDPRINT_EVENTS("Found fd: %d \n", i);
+					DPRINT_EVENTS("Found fd: %d \n", i);
 					FD_SET((unsigned)(i), &inp->cache->fdset);
 				}
 			}
