@@ -1,8 +1,8 @@
-/* $Id: gii-unix.h,v 1.1.1.1 2001/05/12 23:00:14 cegger Exp $
+/* $Id: gii-unix.h,v 1.3 2005/05/01 00:42:30 aldot Exp $
 ******************************************************************************
 
    LibGII UNIX-specific API header file
- 
+
    Copyright (C) 1999 Marcus Sundberg	[marcus@ggi-project.org]
 
    Permission is hereby granted, free of charge, to any person obtaining a
@@ -24,18 +24,19 @@
 
 ******************************************************************************
 */
-              
+
 #ifndef _GGI_GII_UNIX_H
 #define _GGI_GII_UNIX_H
 
 #include <ggi/events.h>
+#include <ggi/gii-defs.h>
 
 
 __BEGIN_DECLS
 /* Wait for filedescriptors and LibGII events the the same time */
-int giiEventSelect(gii_input_t inp, gii_event_mask *mask, int n,
-		   fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
-		   struct timeval *timeout);
+GIIAPIFUNC int giiEventSelect(gii_input_t inp, gii_event_mask *mask, int n,
+			      fd_set *readfds, fd_set *writefds,
+			      fd_set *exceptfds, struct timeval *timeout);
 __END_DECLS
 
 #endif /* GGI_GII_UNIX_H */
