@@ -1,4 +1,4 @@
-/* $Id: xwin.h,v 1.1.1.1.2.1 2004/05/01 21:39:00 cegger Exp $
+/* $Id: xwin.h,v 1.3 2005/03/28 20:33:33 pekberg Exp $
 ******************************************************************************
 
    Xwin inputlib - use an existing X window as a LibGII input source
@@ -33,6 +33,8 @@
 /* Returns non-zero if we should queue the expose event */
 typedef int (gii_inputxwin_exposefunc)(void *arg, int x, int y, int w, int h);
 typedef int (gii_inputxwin_resizefunc)(void *arg, int w, int h, gii_event *ev);
+typedef int (gii_inputxwin_lockfunc)(void *arg);
+typedef int (gii_inputxwin_unlockfunc)(void *arg);
 
 typedef struct {
 	Display *disp;		/* Display to use */
@@ -44,14 +46,20 @@ typedef struct {
 				   the specified function to see if we should
 				   send the expose event or not */
 	void	*exposearg;	/* This is the argument we pass to exposefunc*/
-	void	*gglock;	/* If this is non-null we use it to ggLock()
-				   in the polling function */
 	gii_inputxwin_resizefunc *resizefunc; /* If this is non-null we call
 				   the specified function to fill in a suitable
 				   event to send due to the resize if it returns
 				   0. If it returns non-0, we don't queue any
 				   event. */
 	void	*resizearg;	/* This is the argument we pass to resizefunc*/
+	gii_inputxwin_lockfunc *lockfunc; /* If this is non-null we call
+				   the specified function to lock the polling
+				   function */
+	void	*lockarg;	/* This is the argument we pass to lockfunc */
+	gii_inputxwin_unlockfunc *unlockfunc; /* If this is non-null we call
+				   the specified function to unlock the polling
+				   function */
+	void	*unlockarg;	/* This is the argument we pass to unlockfunc*/
 } gii_inputxwin_arg;
 
 /* Send this event to change parameters on the fly */
