@@ -1,4 +1,4 @@
-/* $Id: eventparse.c,v 1.7 2004/11/27 14:37:51 soyt Exp $
+/* $Id$
 ******************************************************************************
 
    Linux evdev parser
@@ -239,9 +239,6 @@ dispatch_event(struct gii_input *inp, struct input_event *event)
 #endif
 #ifdef EV_FF_STATUS
 	case EV_FF_STATUS:
-#endif
-#ifdef EV_RST
-	case EV_RST:
 #endif
 	default:
 		return 0;
