@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.8 2004/09/16 13:24:59 pekberg Exp $
+/* $Id: input.c,v 1.13 2005/08/04 12:43:29 cegger Exp $
 ******************************************************************************
 
    lk201: input
@@ -29,7 +29,6 @@
 #include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
-#include <ggi/internal/gii_target.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -109,11 +108,11 @@
 #define MAX_KEYS (256)
 
 /* sorry for you non-gcc folks... will rewrite this sometime... */
-static uint32 keylabel[]={
+static uint32_t keylabel[]={
 #include "keytable.dat"
 [0]=GIIK_VOID };
 
-static uint32 keysymShift[]={
+static uint32_t keysymShift[]={
 #include "keysymShift.dat"
 [0]=GIIK_VOID };
 
@@ -135,19 +134,19 @@ typedef struct {
 	char keydown[MAX_KEYS+1];
 	RDSTATE rd_state;
 	int nextdiv;
-	uint32 modifiers;
-	uint32 repeatkey; /* last key pressed, used for repeat */
+	uint32_t modifiers;
+	uint32_t repeatkey; /* last key pressed, used for repeat */
 	unsigned int leds;
 } l_lk201_priv;
 
 #define PRIVP(inp)	((l_lk201_priv*)(inp->priv))
 
-static char *tcgetattrfailstr =
+static const char *tcgetattrfailstr =
 	"Warning: failed to get serial parameters for lk201 device.\n"
 	"         (Is it really a character device?)\n"
 	"         Your keyboard may not work as expected.\n";
 
-static char *tcsetattrfailstr =
+static const char *tcsetattrfailstr =
 	"Warning: failed to set serial parameters for lk201 device.\n"
 	"         (Proper access permisions?)\n"
 	"         Your keyboard may not work as expected.\n";
@@ -203,10 +202,10 @@ GIIsendevent(gii_input *inp, gii_event *ev)
 }
 
 static int 
-do_lk201_open(gii_input *inp, char *filename)
+do_lk201_open(gii_input *inp, const char *filename)
 {
 	l_lk201_priv *priv = (l_lk201_priv*)inp->priv;
-	char tmp[256];
+	uint8_t tmp[256];
 	
 	priv->readonly = 0;
 	priv->fd = open(filename, O_RDWR | O_NOCTTY | O_NONBLOCK);
@@ -219,8 +218,8 @@ do_lk201_open(gii_input *inp, char *filename)
 	
 	if (priv->fd < 0) 
 	{
-		GIIDPRINT_MISC("lk201: Failed to open '%s'.\n",
-			filename);
+		DPRINT_MISC("lk201: Failed to open '%s'.\n",
+			    filename);
 		return GGI_ENODEVICE;
 	}
 	
@@ -230,8 +229,8 @@ do_lk201_open(gii_input *inp, char *filename)
 	}
 	FD_SET(priv->fd, &inp->fdset);
 	
-	GIIDPRINT_MISC("lk201: Opened serial port '%s' %s (fd=%d).\n",
-		filename, priv->readonly ? "ReadOnly" : "Read/Write", priv->fd);
+	DPRINT_MISC("lk201: Opened serial port '%s' %s (fd=%d).\n",
+		    filename, priv->readonly ? "ReadOnly" : "Read/Write", priv->fd);
 	
 	/* Set up the termios state and baud rate */
 	tcflush(priv->fd, TCIOFLUSH);
@@ -279,7 +278,7 @@ static int GII_lk201_close(gii_input *inp)
 {
 	l_lk201_priv *priv = (l_lk201_priv*)inp->priv;
 	
-	GIIDPRINT_MISC("lk201 cleanup\n");
+	DPRINT_MISC("lk201 cleanup\n");
 	
 	if (priv->have_old_termios) {
 		if (tcsetattr(priv->fd, TCSANOW, &priv->old_termios) < 0) {
@@ -290,7 +289,7 @@ static int GII_lk201_close(gii_input *inp)
 	close(priv->fd);
 	free(priv);
 	
-	GIIDPRINT_MISC("lk201: exit OK.\n");
+	DPRINT_MISC("lk201: exit OK.\n");
 	
 	return 0;
 }
@@ -300,7 +299,7 @@ static void lk201_sendbyte(gii_input *inp, unsigned char byte)
 	l_lk201_priv *priv=PRIVP(inp);
 	int fdflags=fcntl(priv->fd, F_GETFL);
 	
-	GIIDPRINT_MISC("lk201_sendbyte: Sending 0x%02x on fd=%d\n", byte, PRIVP(inp)->fd);
+	DPRINT_MISC("lk201_sendbyte: Sending 0x%02x on fd=%d\n", byte, PRIVP(inp)->fd);
 	
 	fcntl(priv->fd, F_SETFL, fdflags & ~O_NONBLOCK);
 	write(priv->fd, (char*)&byte, sizeof(byte));
@@ -309,13 +308,13 @@ static void lk201_sendbyte(gii_input *inp, unsigned char byte)
 
 static void lk201_modechange(gii_input *inp, int mode)
 {
-	GIIDPRINT_MISC("Mode change requested, mode=%d, div=%d, fd=%d\n", mode, PRIVP(inp)->nextdiv, PRIVP(inp)->fd);
+	DPRINT_MISC("Mode change requested, mode=%d, div=%d, fd=%d\n", mode, PRIVP(inp)->nextdiv, PRIVP(inp)->fd);
 	
 	lk201_sendbyte(inp, LK_CMD_MODE(mode, PRIVP(inp)->nextdiv--));
 }
 
 /* this function combines the ev.key.modifiers field with the label to create the symbol */
-static inline void lookup_symbol(gii_input *inp, gii_event *ev, uint32 button)
+static inline void lookup_symbol(gii_input *inp, gii_event *ev, uint32_t button)
 {
 	if (ev->key.modifiers & GII_MOD_SHIFT)
 	{
@@ -373,7 +372,7 @@ static void lk201_updateleds(gii_input *inp)
 static inline void handle_modifier(gii_input *inp, gii_event *ev)
 {
 	l_lk201_priv *priv=PRIVP(inp);
-	uint32 modifier=ev->key.label & GII_KM_MASK;
+	uint32_t modifier=ev->key.label & GII_KM_MASK;
 	
 	/* update the sym field */
 	ev->key.sym=GII_KEY(GII_KT_MOD, modifier);
@@ -408,7 +407,7 @@ static inline void handle_modifier(gii_input *inp, gii_event *ev)
 }
 
 static inline gii_event_mask
-GII_create_key_event(gii_input *inp, uint8 evtype, uint32 button)
+GII_create_key_event(gii_input *inp, uint8_t evtype, uint32_t button)
 {
 	gii_event ev;
 	gii_event_mask retval=0;
@@ -450,7 +449,7 @@ GII_create_key_event(gii_input *inp, uint8 evtype, uint32 button)
 		}
 	}
 	
-	GIIDPRINT_EVENTS("KEY-%s(0x%02x) button=0x%02x modifiers=0x%02x "
+	DPRINT_EVENTS("KEY-%s(0x%02x) button=0x%02x modifiers=0x%02x "
 		"sym=0x%04x label=0x%04x\n",
 		(ev.key.type == evKeyRelease) ? "UP" : 
 		((ev.key.type == evKeyPress) ? "DN" : "RP"), ev.key.type,
@@ -477,7 +476,7 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 	gii_event_mask mask=0;
 	int loop;
 	
-	GIIDPRINT_MISC("GII_keyboard_handle_data: Byte 0x%2x (%3d) received, state=%d\n", key, key, priv->rd_state);
+	DPRINT_MISC("GII_keyboard_handle_data: Byte 0x%2x (%3d) received, state=%d\n", key, key, priv->rd_state);
 	
 	switch (priv->rd_state)	{
 	case RDST_IDLE:
@@ -499,12 +498,12 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 
 				priv->nextdiv--;
 
-				GIIDPRINT_MISC("GII_keyboard_handle_data: Keyboard reset successfully\n");
+				DPRINT_MISC("GII_keyboard_handle_data: Keyboard reset successfully\n");
 				/* ring the bell */
 				/* lk201_sendbyte(inp, LK_RING_BELL); */
 			} else {
 				/* all of the keyboard modes have been set */
-				GIIDPRINT_MISC("GII_keyboard_handle_data: lk401 keyboard detected\n");
+				DPRINT_MISC("GII_keyboard_handle_data: lk401 keyboard detected\n");
 			}
 			break;
 					
@@ -516,7 +515,7 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 		case LK_ALLUP:
 			for (loop=0; loop<=MAX_KEYS; loop++) {
 				if (priv->keydown[loop]) {
-					GIIDPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x released\n", loop);
+					DPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x released\n", loop);
 
 					priv->keydown[loop]=0;
 
@@ -526,21 +525,21 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 			break;
 			
 		case LK_INPUT_ERROR:
-			GIIDPRINT_MISC("GII_keyboard_handle_data: Keyboard has indicated an input error. (lk201 keyboard detected?)\n");
+			DPRINT_MISC("GII_keyboard_handle_data: Keyboard has indicated an input error. (lk201 keyboard detected?)\n");
 			
 			break;
 			
 		default:
 			if (keylabel[key]) {
 				if (priv->keydown[key]) {
-					GIIDPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x released\n", key);
+					DPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x released\n", key);
 							
 					priv->keydown[key]=0;
 					
 					mask|=GII_create_key_event(inp, evKeyRelease, key);
 							
 				} else {
-					GIIDPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x pressed\n", key);
+					DPRINT_MISC("GII_keyboard_handle_data: Key 0x%02x pressed\n", key);
 
 					priv->keydown[key]=1;
 					mask|=GII_create_key_event(inp, evKeyPress, key);
@@ -549,7 +548,7 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 						
 						
 			} else {
-				GIIDPRINT_MISC("GII_keyboard_handle_data: Unknown value %d (0x%x) received from keyboard\n", key, key);
+				DPRINT_MISC("GII_keyboard_handle_data: Unknown value %d (0x%x) received from keyboard\n", key, key);
 			}
 			break;
 		}
@@ -575,7 +574,7 @@ GII_keyboard_handle_data(gii_input *inp, unsigned char key)
 		break;
 
 		default:
-			GIIDPRINT_MISC("GII_keyboard_handle_data: Unknown state\n");
+			DPRINT_MISC("GII_keyboard_handle_data: Unknown state\n");
 
 			priv->rd_state=RDST_IDLE;
 			break;
@@ -591,7 +590,7 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 	gii_event_mask result = 0;
 	int readlen, i;
 	
-	GIIDPRINT_EVENTS("GII_keyboard_poll(%p, %p) called\n", inp, arg);
+	DPRINT_EVENTS("GII_keyboard_poll(%p, %p) called\n", inp, arg);
 	
 	if (priv->eof) {
 		/* End-of-file, don't do any polling */
@@ -607,7 +606,7 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 	} else {
 		if (! FD_ISSET(priv->fd, ((fd_set*)arg))) {
 			/* Nothing to read on our fd */
-			GIIDPRINT_EVENTS("GII_keyboard_poll: dummypoll\n");
+			DPRINT_EVENTS("GII_keyboard_poll: dummypoll\n");
 			return 0;
 		}
 	}
@@ -632,7 +631,7 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 		if (errno != EINTR) {
 			priv->eof = 1;
 		}
-		GIIDPRINT_EVENTS("Linux-kbd: EOF occured on fd: %d\n",
+		DPRINT_EVENTS("Linux-kbd: EOF occured on fd: %d\n",
 			priv->fd);
 	} else if (readlen < 0) {
 		/* Error, we try again next time */
@@ -643,25 +642,27 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_lk201(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_lk201(gii_input *inp, const char *args, void *argptr)
 {
 	l_lk201_priv *priv;
-	char *devname=getenv("GII_LK201_OPTIONS");
+	const char *_devname = getenv("GII_LK201_OPTIONS");
 	int i;
 	
-	GIIDPRINT_MISC("lk201 starting.(args=\"%s\",argptr=%p)\n",
+	DPRINT_MISC("lk201 starting.(args=\"%s\",argptr=%p)\n",
 		args, argptr);
 	
 	/* Initialize */
 	if (args && *args) {
-		devname = (char *) args;
+		_devname = args;
 	}
 	
 	/* parse the device options here */
 	
-	GIIDPRINT_MISC("lk201: dev=`%s'\n",devname);
+	DPRINT_MISC("lk201: dev=`%s'\n", _devname);
 	
-	if (!devname || *devname == '\0') {
+	if (!_devname || *_devname == '\0') {
 		return GGI_EARGINVAL;
 	}
 	
@@ -682,9 +683,9 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	priv->modifiers=0;
 	priv->leds=0;
 	
-	bzero(priv->keydown, sizeof(priv->keydown));
+	memset(priv->keydown, 0, sizeof(priv->keydown));
 	
-	if ((i = do_lk201_open(inp, devname)) < 0) {
+	if ((i = do_lk201_open(inp, _devname)) < 0) {
 		free(priv);
 		return i;
 	}
@@ -698,7 +699,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	send_devinfo(inp);
 	
-	GIIDPRINT_MISC("lk201 fully up\n");
+	DPRINT_MISC("lk201 fully up\n");
 	
 	return 0;
 }
